Index: chrome/browser/browser.h |
diff --git a/chrome/browser/browser.h b/chrome/browser/browser.h |
index a6c15c2848a80cc7f598b2c1275adf1b26a27780..2372f9542df82d87c7e8bf845d70bc8dbefe4930 100644 |
--- a/chrome/browser/browser.h |
+++ b/chrome/browser/browser.h |
@@ -168,7 +168,10 @@ class Browser : public TabStripModelDelegate, |
static void OpenApplicationWindow(Profile* profile, const GURL& url); |
#if defined(OS_MACOSX) |
- // Open a new window with help (needed on Mac when there are no windows). |
+ // Open a new window with history/downloads/help (needed on Mac when there are |
+ // no windows). |
+ static void OpenHistoryWindow(Profile* profile); |
+ static void OpenDownloadsWindow(Profile* profile); |
static void OpenHelpWindow(Profile* profile); |
#endif |